|
Package: |
| HW.pval |
|
Type: |
| Package |
|
Version: |
| 1.0 |
|
Date: |
| 2012-06-22 |
|
License: |
| GPL-3 |
Tests a matrix of observed genotype counts for a multiallelic gene and returns plain and/or fully conditional P-values. The P-values are found by running the function HW.pval(). The P-values for the following test statistics are returned: Root Mean Square, Chi Square, and the Log Likelihood Ratio.The matrix of observed genotype counts is a matrix of dimension r by r, where r is the number of alleles A_1, A_2,...,A_r. The (j,k)-th entry of the matrix is the observed number of genotypes (A_j,A_k).